@@ -50,6 +50,8 @@ class Channel:
         The id of the channel
     channel_type: ChannelType
         The type of the channel
+    server_id: Optional[:class:`str`]
+        The server id of the chanel, if any
     """
     __slots__ = ("state", "id", "channel_type", "server_id")
 
@@ -57,7 +59,7 @@ class Channel:
         self.state = state
         self.id = data["_id"]
         self.channel_type = ChannelType(data["channel_type"])
-        self.server_id = ""
+        self.server_id: Optional[str] = None
 
     async def _get_channel_id(self) -> str:
         return self.id
@@ -72,8 +74,17 @@ class Channel:
     @property
     def server(self) -> Server:
         """:class:`Server` The server this voice channel belongs too"""
+        if not self.server_id:
+            raise IndexError
+
         return self.state.get_server(self.server_id)
 
+    @property
+    def mention(self) -> str:
+        """:class:`str`: Returns a string that allows you to mention the given channel."""
+        return f"<#{self.id}>"
+
+
 class SavedMessageChannel(Channel, Messageable):
     """The Saved Message Channel"""
     def __init__(self, data: SavedMessagesPayload, state: State):
@@ -99,33 +110,37 @@ class GroupDMChannel(Channel, Messageable, EditableChannel):
         The icon of the group dm channel
     permissions: :class:`ChannelPermissions`
         The permissions of the users inside the group dm channel
+    description: Optional[:class:`str`]
+        The description of the channel, if any
     """
 
-    __slots__ = ("recipients", "name", "owner", "permissions", "icon")
+    __slots__ = ("recipients", "name", "owner", "permissions", "icon", "description")
 
     def __init__(self, data: GroupDMChannelPayload, state: State):
         super().__init__(data, state)
         self.recipients = [state.get_user(user_id) for user_id in data["recipients"]]
         self.name = data["name"]
         self.owner = state.get_user(data["owner"])
+        self.description: Optional[str] = data.get("description")
 
         if icon := data.get("icon"):
             self.icon = Asset(icon, state)
         else:
             self.icon = None
 
-        if perms := data.get("permissions"):
-            self.permissions = ChannelPermissions._from_value(perms)
-        else:
-            self.permissions = ChannelPermissions._from_value(0)
+        perms = data.get("permissions", 0)
+        self.permissions = ChannelPermissions._from_value(perms)
 
-    def _update(self, *, name: Optional[str] = None, recipients: Optional[list[str]] = None):
+    def _update(self, *, name: Optional[str] = None, recipients: Optional[list[str]] = None, description: Optional[str] = None):
         if name:
             self.name = name
 
         if recipients:
             self.recipients = [self.state.get_user(user_id) for user_id in recipients]
 
+        if description:
+            self.description = description
+
     async def set_default_permissions(self, permissions: ChannelPermissions) -> None:
         """Sets the default permissions for a group.
         Parameters
@@ -154,13 +169,15 @@ class TextChannel(Channel, Messageable, EditableChannel):
         A dictionary of role id's to the permissions of that role in the text channel
     icon: Optional[:class:`Asset`]
         The icon of the text channel, if any
+    description: Optional[:class:`str`]
+        The description of the channel, if any
     """
     def __init__(self, data: TextChannelPayload, state: State):
         super().__init__(data, state)
 
         self.server_id = data["server"]
         self.name = data["name"]
-        self.description = data.get("description")
+        self.description: Optional[str] = data.get("description")
 
         last_message_id = data.get("last_message")
         self.last_message_id = last_message_id
@@ -173,7 +190,7 @@ class TextChannel(Channel, Messageable, EditableChannel):
         else:
             self.icon = None
 
-    def _get_channel_id(self) -> str:
+    async def _get_channel_id(self) -> str:
         return self.id
 
     @property
@@ -232,23 +249,22 @@ class VoiceChannel(Channel, EditableChannel):
         A dictionary of role id's to the permissions of that role in the voice channel
     icon: Optional[:class:`Asset`]
         The icon of the voice channel, if any
+    description: Optional[:class:`str`]
+        The description of the channel, if any
     """
     def __init__(self, data: VoiceChannelPayload, state: State):
         super().__init__(data, state)
 
         self.server_id = data["server"]
         self.name = data["name"]
-        self.description = data.get("description")
+        self.description: Optional[str] = data.get("description")
 
         if perms := data.get("default_permissions"):
             self.default_permissions = ChannelPermissions._from_value(perms)
         else:
             self.default_permissions = ChannelPermissions._from_value(0)
 
-        if role_perms := data.get("role_permissions"):
-            self.role_permissions = {role_id: ChannelPermissions._from_value(perms) for role_id, perms in role_perms.items()}
-        else:
-            self.role_permissions = {}
+        self.role_permissions = {role_id: ChannelPermissions._from_value(perms) for role_id, perms in data.get("role_permissions", {}).items()}
 
         if icon := data.get("icon"):
             self.icon = Asset(icon, state)
@@ -281,7 +297,7 @@ class VoiceChannel(Channel, EditableChannel):
         await self.state.http.set_channel_role_permissions(self.id, role.id, permissions.value)
 
 def channel_factory(data: ChannelPayload, state: State) -> Union[DMChannel, GroupDMChannel, SavedMessageChannel, TextChannel, VoiceChannel]:
-    if data["channel_type"] == "SavedMessage":
+    if data["channel_type"] == "SavedMessages":
         return SavedMessageChannel(data, state)
     elif data["channel_type"] == "DirectMessage":
         return DMChannel(data, state)
