@@ -13,6 +13,7 @@ from .invite import Invite
 from .message import Message
 from .state import State
 from .websocket import WebsocketHandler
+from .utils import Missing
 
 try:
     import ujson as json
@@ -32,7 +33,7 @@ logger = logging.getLogger("revolt")
 
 class Client:
     """The client for interacting with revolt
-    
+
     Parameters
     -----------
     session: :class:`aiohttp.ClientSession`
@@ -44,13 +45,14 @@ class Client:
     max_messages: :class:`int`
         The max amount of messages stored in the cache, by default this is 5k
     """
-    
-    def __init__(self, session: aiohttp.ClientSession, token: str, api_url: str = "https://api.revolt.chat", max_messages: int = 5000):
+
+    def __init__(self, session: aiohttp.ClientSession, token: str, *, api_url: str = "https://api.revolt.chat", max_messages: int = 5000, bot: bool = True):
         self.session = session
         self.token = token
         self.api_url = api_url
         self.max_messages = max_messages
-        
+        self.bot = bot
+
         self.api_info: ApiInfo
         self.http: HttpClient
         self.state: State
@@ -62,7 +64,7 @@ class Client:
 
     def dispatch(self, event: str, *args: Any):
         """Dispatch an event, this is typically used for testing and internals.
-        
+
         Parameters
         ----------
         event: class:`str`
@@ -90,7 +92,7 @@ class Client:
         api_info = await self.get_api_info()
 
         self.api_info = api_info
-        self.http = HttpClient(self.session, self.token, self.api_url, self.api_info)
+        self.http = HttpClient(self.session, self.token, self.api_url, self.api_info, self.bot)
         self.state = State(self.http, api_info, self.max_messages)
         self.websocket = WebsocketHandler(self.session, self.token, api_info["ws"], self.dispatch, self.state)
         await self.websocket.start()
@@ -183,6 +185,11 @@ class Client:
         """list[:class:`User`] All users the client can see"""
         return list(self.state.users.values())
 
+    @property
+    def servers(self) -> list[Server]:
+        """list[:class:'Server'] All servers the client can see"""
+        return list(self.state.servers.values())
+
     async def fetch_user(self, user_id: str) -> User:
         """Fetchs a user
 
@@ -284,3 +291,61 @@ class Client:
                 return message
 
         raise LookupError
+
+    async def edit_self(self, **kwargs):
+        """Edits the client's own user
+
+        Parameters
+        -----------
+        avatar: Optional[:class:`File`]
+            The avatar to change to, passing in ``None`` will remove the avatar
+        """
+        if kwargs.get("avatar", Missing) == None:
+            del kwargs["avatar"]
+            remove = "Avatar"
+        else:
+            remove = None
+
+        await self.state.http.edit_self(remove, kwargs)
+
+    async def edit_status(self, **kwargs):
+        """Edits the client's own status
+
+        Parameters
+        -----------
+        presence: :class:`PresenceType`
+            The presence to change to
+        text: Optional[:class:`str`]
+            The text to change the status to, passing in ``None`` will remove the status
+        """
+        if kwargs.get("text", Missing) == None:
+            del kwargs["text"]
+            remove = "StatusText"
+        else:
+            remove = None
+
+        if presence := kwargs.get("presence"):
+            kwargs["presence"] = presence.value
+
+        await self.state.http.edit_self(remove, {"status": kwargs})
+
+    async def edit_profile(self, **kwargs):
+        """Edits the client's own profile
+
+        Parameters
+        -----------
+        content: Optional[:class:`str`]
+            The new content for the profile, passing in ``None`` will remove the profile content
+        background: Optional[:class:`File`]
+            The new background for the profile, passing in ``None`` will remove the profile background
+        """
+        if kwargs.get("content", Missing) == None:
+            del kwargs["content"]
+            remove = "ProfileContent"
+        elif kwargs.get("background", Missing) == None:
+            del kwargs["background"]
+            remove = "ProfileBackground"
+        else:
+            remove = None
+
+        await self.state.http.edit_self(remove, {"profile": kwargs})
