@@ -6,6 +6,8 @@ from typing import (TYPE_CHECKING, Any, Coroutine, Literal, Optional, TypeVar,
 import aiohttp
 import ulid
 
+from revolt.utils import Missing
+
 from .errors import HTTPError, ServerError
 from .file import File
 
@@ -30,7 +32,7 @@ if TYPE_CHECKING:
                         PartialInvite, Role, Server, ServerBans, TextChannel)
     from .types import User as UserPayload
     from .types import UserProfile, VoiceChannel, GroupDMChannel, Member
-
+    from .types import SendableEmbed as SendableEmbedPayload
 
 __all__ = ("HttpClient",)
 
@@ -38,22 +40,23 @@ T = TypeVar("T")
 Request = Coroutine[Any, Any, T]
 
 class HttpClient:
-    __slots__ = ("session", "token", "api_url", "api_info")
+    __slots__ = ("session", "token", "api_url", "api_info", "auth_header")
 
-    def __init__(self, session: aiohttp.ClientSession, token: str, api_url: str, api_info: ApiInfo):
+    def __init__(self, session: aiohttp.ClientSession, token: str, api_url: str, api_info: ApiInfo, bot: bool = True):
         self.session = session
         self.token = token
         self.api_url = api_url
         self.api_info = api_info
+        self.auth_header = "x-bot-token" if bot else "x-session-token"
 
     async def request(self, method: Literal["GET", "POST", "PUT", "DELETE", "PATCH"], route: str, *, json: Optional[dict[str, Any]] = None, nonce: bool = True, params: Optional[dict[str, Any]] = None) -> Any:
         url = f"{self.api_url}{route}"
 
         kwargs = {}
-        
+
         headers = {
             "User-Agent": "Revolt.py (https://github.com/revoltchat/revolt.py)",
-            "x-bot-token": self.token
+            self.auth_header: self.token
         }
 
         if json:
@@ -72,7 +75,10 @@ class HttpClient:
         async with self.session.request(method, url, **kwargs) as resp:
             text = await resp.text()
             if text:
-                response = _json.loads(await resp.text())
+                try:
+                    response = _json.loads(await resp.text())
+                except ValueError:
+                    raise HTTPError(f"Invalid json response:\n{text}") from None
             else:
                 response = text
 
@@ -105,7 +111,7 @@ class HttpClient:
         else:
             return response
 
-    async def send_message(self, channel: str, content: Optional[str], embeds: Optional[list[EmbedPayload]], attachments: Optional[list[File]], replies: Optional[list[MessageReplyPayload]], masquerade: Optional[MasqueradePayload]) -> MessagePayload:
+    async def send_message(self, channel: str, content: Optional[str], embeds: Optional[list[SendableEmbedPayload]], attachments: Optional[list[File]], replies: Optional[list[MessageReplyPayload]], masquerade: Optional[MasqueradePayload]) -> MessagePayload:
         json: dict[str, Any] = {}
 
         if content:
@@ -131,8 +137,15 @@ class HttpClient:
 
         return await self.request("POST", f"/channels/{channel}/messages", json=json)
 
-    def edit_message(self, channel: str, message: str, content: str) -> Request[None]:
-        json = {"content": content}
+    def edit_message(self, channel: str, message: str, content: Optional[str], embeds: Optional[list[SendableEmbedPayload]] = None) -> Request[None]:
+        json = {}
+
+        if content is not None:
+            json["content"] = content
+
+        if embeds is not None:
+            json["embeds"] = embeds
+
         return self.request("PATCH", f"/channels/{channel}/messages/{message}", json=json)
 
     def delete_message(self, channel: str, message: str) -> Request[None]:
@@ -377,3 +390,25 @@ class HttpClient:
             values["remove"] = remove
 
         return self.request("PATCH", f"/servers/{server_id}/roles/{role_id}", json=values)
+
+    async def edit_self(self, remove: Optional[str], values: dict[str, Any]):
+        if remove:
+            values["remove"] = remove
+
+        if avatar := values.get("avatar"):
+            asset = await self.upload_file(avatar, "avatars")
+            values["avatar"] = asset["id"]
+
+        if profile := values.get("profile"):
+            if background := profile.background():
+                asset = await self.upload_file(background, "backgrounds")
+                profile["background"] = asset["id"]
+
+        if not values.get("profile", Missing):
+            del values["profile"]
+
+        if not values.get("status", Missing):
+            del values["status"]
+
+        print(remove, values)
+        return await self.request("PATCH", "/users/@me", json=values)
