@@ -1,6 +1,7 @@
 from __future__ import annotations
 
 from typing import TYPE_CHECKING, TypedDict
+from typing_extensions import NotRequired
 
 if TYPE_CHECKING:
     from .file import File
@@ -8,14 +9,12 @@ if TYPE_CHECKING:
 
 __all__ = ("Member",)
 
-class _MemberOptional(TypedDict, total=False):
-    nickname: str
-    avatar: File
-    roles: list[str]
-
 class MemberID(TypedDict):
     server: str
     user: str
 
-class Member(_MemberOptional):
+class Member(TypedDict):
     _id: MemberID
+    nickname: NotRequired[str]
+    avatar: NotRequired[File]
+    roles: NotRequired[list[str]]
