@@ -15,7 +15,7 @@ if TYPE_CHECKING:
     from .types import User as UserPayload
 
 
-__all__ = ("User",)
+__all__ = ("User", "Status", "Relation", "UserProfile")
 
 class Relation(NamedTuple):
     """A namedtuple representing a relation between the bot and a user"""
@@ -82,7 +82,7 @@ class User(Messageable):
         avatar = data.get("avatar")
         self.original_avatar = Asset(avatar, state) if avatar else None
 
-        relations = []
+        relations: list[Relation] = []
 
         for relation in data.get("relations", []):
             user = state.get_user(relation["_id"])
@@ -131,6 +131,11 @@ class User(Messageable):
         """Optional[:class:`Asset`] The avatar the member is displaying, this includes there orginal avatar and masqueraded avatar"""
         return self.masquerade_avatar or self.original_avatar
 
+    @property
+    def mention(self) -> str:
+        """:class:`str`: Returns a string that allows you to mention the given user."""
+        return f"<@{self.id}>"
+
     def _update(self, *, status: Optional[StatusPayload] = None, profile_content: Optional[str] = None, profile_background: Optional[File] = None, avatar: Optional[File] = None, online: Optional[bool] = None):
         if status:
             presence = status.get("presence")
@@ -166,6 +171,9 @@ class User(Messageable):
         :class:`UserProfile`
             The user's profile
         """
+        if profile := self.profile:
+            return profile
+
         payload = await self.state.http.fetch_profile(self.id)
 
         if file := payload.get("background"):
@@ -173,4 +181,5 @@ class User(Messageable):
         else:
             background = None
 
-        return UserProfile(payload.get("content"), background)
+        self.profile = UserProfile(payload.get("content"), background)
+        return self.profile
